==> liquidwar6-0.0.1beta.tar.gz: liquidwar6-0.0.1beta/src/lib/gfx/mod-gl/gl-menu/gl-menu-register.c <==
/*
  Liquid War 6 is a unique multiplayer wargame.
  Copyright (C)  2005, 2006  Christian Mauduit <ufoot@ufoot.org>

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
  Contact author        : ufoot@ufoot.org
*/

#include <string.h>

#include "config.h"
#include "../mod-gl.h"

#include "gl-cylinder/gl-cylinder.h"

MOD_GL_MENU_BACKEND *
mod_gl_menu_create_backend (MOD_GL_UTILS_CONTEXT * utils_context, char *name)
{
  MOD_GL_MENU_BACKEND *(*init_func) (MOD_GL_UTILS_CONTEXT * utils_context) =
    NULL;
  MOD_GL_MENU_BACKEND *backend = NULL;

  if (strcmp (name, "cylinder") == 0)
    {
      init_func = mod_gl_menu_cylinder_create_backend;
    }
  else
    {
      lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
		  _("menu backend \"%s\" does not exists"), name);
    }

  if (init_func)
    {
      backend = init_func (utils_context);
      if (backend)
	{
	  backend->backend_name = lw6sys_str_copy (name);
	}
    }

  return backend;
}

void
mod_gl_menu_destroy_backend (MOD_GL_UTILS_CONTEXT * utils_context,
			     MOD_GL_MENU_BACKEND * backend)
{
  if (backend)
    {
      if (backend->backend_name)
	{
	  LW6SYS_FREE (backend->backend_name);
	}
      LW6SYS_FREE (backend);
    }
}

==> liquidwar6-0.0.2beta.tar.gz: liquidwar6-0.0.2beta/src/lib/gfx/mod-gl/gl-menu/gl-menu-register.c <==
/*
  Liquid War 6 is a unique multiplayer wargame.
  Copyright (C)  2005, 2006, 2007  Christian Mauduit <ufoot@ufoot.org>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  

  Liquid War 6 homepage : http://www.gnu.org/software/liquidwar6/
  Contact author        : ufoot@ufoot.org
*/

#include <string.h>

#include "config.h"
#include "../mod-gl.h"

#include "gl-cylinder/gl-cylinder.h"

MOD_GL_MENU_BACKEND *
mod_gl_menu_create_backend (MOD_GL_UTILS_CONTEXT * utils_context, char *name)
{
  MOD_GL_MENU_BACKEND *(*init_func) (MOD_GL_UTILS_CONTEXT * utils_context) =
    NULL;
  MOD_GL_MENU_BACKEND *backend = NULL;

  if (strcmp (name, "cylinder") == 0)
    {
      init_func = mod_gl_menu_cylinder_create_backend;
    }
  else
    {
      lw6sys_log (LW6SYS_LOG_WARNING, "gfx-mod-gl",
		  _("menu backend \"%s\" does not exists"), name);
    }

  if (init_func)
    {
      backend = init_func (utils_context);
      if (backend)
	{
	  backend->backend_name = lw6sys_str_copy (name);
	}
    }

  return backend;
}

void
mod_gl_menu_destroy_backend (MOD_GL_UTILS_CONTEXT * utils_context,
			     MOD_GL_MENU_BACKEND * backend)
{
  if (backend)
    {
      if (backend->backend_name)
	{
	  LW6SYS_FREE (backend->backend_name);
	}
      LW6SYS_FREE (backend);
    }
}
